==> teplotech-markup-1.0.3.tgz: package/src/scripts/components/Modal.js <==
var Modal = function(element, options) {
	this.options             = $.extend({}, Modal.DEFAULTS, options)
	this.$body               = $(document.body)
	this.$element            = $(element)
	this.$dialog             = this.$element.find('.modal__dialog')
	this.$backdrop           = null
	this.isShown             = null
	this.originalBodyPad     = null
	this.scrollbarWidth      = 0
	this.ignoreBackdropClick = false

	if (this.options.remote) {
		this.$element
			.find('.modal__content')
			.load(this.options.remote, $.proxy(function () {
				this.$element.trigger('loaded.modal')
			}, this))
	}
}

Modal.TRANSITION_DURATION = 300
Modal.BACKDROP_TRANSITION_DURATION = 150

Modal.DEFAULTS = {
	backdrop: true,
	keyboard: true,
	show: true
}

$.extend(Modal.prototype, {
	toggle: function(_relatedTarget) {
		return this.isShown ? this.hide() : this.show(_relatedTarget)
	},
	show: function (_relatedTarget) {
		var that = this
		var e    = $.Event('show.modal', { relatedTarget: _relatedTarget })

		this.$element.trigger(e)

		if (this.isShown || e.isDefaultPrevented()) return

		this.isShown = true

		this.checkScrollbar()
		this.setScrollbar()
		this.$body.addClass('modal-open')

		this.escape()
		this.resize()

		this.$element.on('click.dismiss.modal', '[data-dismiss="modal"]', $.proxy(this.hide, this))

		this.$dialog.on('mousedown.dismiss.modal', function () {
			that.$element.one('mouseup.dismiss.modal', function (e) {
				if ($(e.target).is(that.$element)) that.ignoreBackdropClick = true
			})
		})

		this.backdrop(function () {
			var transition = $.support.transition && that.$element.hasClass('fade')

			if (!that.$element.parent().length) {
				that.$element.appendTo(that.$body) // don't move modals dom position
			}

			that.$element
				.show()
				.scrollTop(0)

			that.adjustDialog()

			if (transition) {
				that.$element[0].offsetWidth // force reflow
			}

			that.$element.addClass('in')

			that.enforceFocus()

			var e = $.Event('shown.modal', { relatedTarget: _relatedTarget })

			transition ?
				that.$dialog // wait for modal to slide in
					.one('bsTransitionEnd', function () {
						that.$element.trigger('focus').trigger(e)
					})
					.emulateTransitionEnd(Modal.TRANSITION_DURATION) :
				that.$element.trigger('focus').trigger(e)
		})
	},
	hide: function(e) {
		if (e) e.preventDefault()

		e = $.Event('hide.modal')

		this.$element.trigger(e)

		if (!this.isShown || e.isDefaultPrevented()) return

		this.isShown = false

		this.escape()
		this.resize()

		$(document).off('focusin.modal')

		this.$element
			.removeClass('in')
			.off('click.dismiss.modal')
			.off('mouseup.dismiss.modal')

		this.$dialog.off('mousedown.dismiss.modal')

		$.support.transition && this.$element.hasClass('fade') ?
			this.$element
				.one('bsTransitionEnd', $.proxy(this.hideModal, this))
				.emulateTransitionEnd(Modal.TRANSITION_DURATION) :
			this.hideModal()
	},
	enforceFocus: function() {
		$(document)
			.off('focusin.modal') // guard against infinite focus loop
			.on('focusin.modal', $.proxy(function (e) {
				if (this.$element[0] !== e.target && !this.$element.has(e.target).length) {
					this.$element.trigger('focus')
				}
			}, this))
	},
	escape: function() {
		if (this.isShown && this.options.keyboard) {
			this.$element.on('keydown.dismiss.modal', $.proxy(function(e) {
				e.which == 27 && this.hide()
			}, this))
		} else if (!this.isShown) {
			this.$element.off('keydown.dismiss.modal')
		}
	},
	resize: function() {
		if (this.isShown) {
			$(window).on('resize.modal', $.proxy(this.handleUpdate, this))
		} else {
			$(window).off('resize.modal')
		}
	},
	hideModal: function() {
		var that = this
		this.$element.hide()
		this.backdrop(function() {
			that.$body.removeClass('modal-open')
			that.resetAdjustments()
			that.resetScrollbar()
			that.$element.trigger('hidden.modal')
		})
	},
	removeBackdrop: function() {
		this.$backdrop && this.$backdrop.remove()
		this.$backdrop = null
	},
	backdrop: function(callback) {
		var that = this
		var animate = this.$element.hasClass('fade') ? 'fade' : ''

		if (this.isShown && this.options.backdrop) {
			var doAnimate = $.support.transition && animate

			this.$backdrop = $(document.createElement('div'))
				.addClass('modal-backdrop ' + animate)
				.appendTo(this.$body)

			this.$element.on('click.dismiss.modal', $.proxy(function (e) {
				if (this.ignoreBackdropClick) {
					this.ignoreBackdropClick = false
					return
				}
				if (e.target !== e.currentTarget) return
				this.options.backdrop == 'static'
					? this.$element[0].focus()
					: this.hide()
			}, this))

			if (doAnimate) this.$backdrop[0].offsetWidth // force reflow

			this.$backdrop.addClass('in')

			if (!callback) return

			doAnimate ?
				this.$backdrop
					.one('bsTransitionEnd', callback)
					.emulateTransitionEnd(Modal.BACKDROP_TRANSITION_DURATION) :
				callback()

		} else if (!this.isShown && this.$backdrop) {
			this.$backdrop.removeClass('in')

			var callbackRemove = function () {
				that.removeBackdrop()
				callback && callback()
			}
			$.support.transition && this.$element.hasClass('fade') ?
				this.$backdrop
					.one('bsTransitionEnd', callbackRemove)
					.emulateTransitionEnd(Modal.BACKDROP_TRANSITION_DURATION) :
				callbackRemove()

		} else if (callback) {
			callback()
		}
	},
	// these following methods are used to handle overflowing modals
	handleUpdate: function() {
		this.adjustDialog()
	},
	adjustDialog: function() {
		var modalIsOverflowing = this.$element[0].scrollHeight > document.documentElement.clientHeight

		this.$element.css({
			paddingLeft:  !this.bodyIsOverflowing && modalIsOverflowing ? this.scrollbarWidth : '',
			paddingRight: this.bodyIsOverflowing && !modalIsOverflowing ? this.scrollbarWidth : ''
		})
	},
	resetAdjustments: function() {
		this.$element.css({
			paddingLeft: '',
			paddingRight: ''
		})
	},
	checkScrollbar: function() {
		var fullWindowWidth = window.innerWidth
		if (!fullWindowWidth) { // workaround for missing window.innerWidth in IE8
			var documentElementRect = document.documentElement.getBoundingClientRect()
			fullWindowWidth = documentElementRect.right - Math.abs(documentElementRect.left)
		}
		this.bodyIsOverflowing = document.body.clientWidth < fullWindowWidth
		this.scrollbarWidth = this.measureScrollbar()
	},
	setScrollbar: function() {
		var bodyPad = parseInt((this.$body.css('padding-right') || 0), 10)
		this.originalBodyPad = document.body.style.paddingRight || ''
		if (this.bodyIsOverflowing) this.$body.css('padding-right', bodyPad + this.scrollbarWidth)
	},
	resetScrollbar: function() {
		this.$body.css('padding-right', this.originalBodyPad)
	},
	measureScrollbar: function() {
		var scrollDiv = document.createElement('div')
		scrollDiv.className = 'modal-scrollbar-measure'
		this.$body.append(scrollDiv)
		var scrollbarWidth = scrollDiv.offsetWidth - scrollDiv.clientWidth
		this.$body[0].removeChild(scrollDiv)
		return scrollbarWidth
	}
})

module.exports = Modal

==> teplotech-markup-1.1.4.tgz: package/src/scripts/components/Modal.js <==
'use strict'

var Modal = function(element, options) {
	this.options             = $.extend({}, Modal.DEFAULTS, options)
	this.$body               = $(document.body)
	this.$element            = $(element)
	this.$dialog             = this.$element.find('.modal__dialog')
	this.$backdrop           = null
	this.isShown             = null
	this.originalBodyPad     = null
	this.scrollbarWidth      = 0
	this.ignoreBackdropClick = false

	if (this.options.remote) {
		this.$element
			.find('.modal__content')
			.load(this.options.remote, $.proxy(function () {
				this.$element.trigger('loaded.modal')
			}, this))
	}
}

Modal.TRANSITION_DURATION = 300
Modal.BACKDROP_TRANSITION_DURATION = 150

Modal.DEFAULTS = {
	backdrop: true,
	keyboard: true,
	show: true
}

Object.assign(Modal.prototype, {
	toggle: function(_relatedTarget) {
		return this.isShown ? this.hide() : this.show(_relatedTarget)
	},
	show: function (_relatedTarget) {
		var that = this
		var e    = $.Event('show.modal', { relatedTarget: _relatedTarget })

		this.$element.trigger(e)

		if (this.isShown || e.isDefaultPrevented()) return

		this.isShown = true

		this.checkScrollbar()
		this.setScrollbar()
		this.$body.addClass('modal-open')

		this.escape()
		this.resize()

		this.$element.on('click.dismiss.modal', '[data-dismiss="modal"]', $.proxy(this.hide, this))

		this.$dialog.on('mousedown.dismiss.modal', function () {
			that.$element.one('mouseup.dismiss.modal', function (e) {
				if ($(e.target).is(that.$element)) that.ignoreBackdropClick = true
			})
		})

		this.backdrop(function () {
			var transition = $.support.transition && that.$element.hasClass('fade')

			if (!that.$element.parent().length) {
				that.$element.appendTo(that.$body) // don't move modals dom position
			}

			that.$element
				.show()
				.scrollTop(0)

			that.adjustDialog()

			if (transition) {
				that.$element[0].offsetWidth // force reflow
			}

			that.$element.addClass('in')

			that.enforceFocus()

			var e = $.Event('shown.modal', { relatedTarget: _relatedTarget })

			transition ?
				that.$dialog // wait for modal to slide in
					.one('bsTransitionEnd', function () {
						that.$element.trigger('focus').trigger(e)
					})
					.emulateTransitionEnd(Modal.TRANSITION_DURATION) :
				that.$element.trigger('focus').trigger(e)
		})
	},
	hide: function(e) {
		if (e) e.preventDefault()

		e = $.Event('hide.modal')

		this.$element.trigger(e)

		if (!this.isShown || e.isDefaultPrevented()) return

		this.isShown = false

		this.escape()
		this.resize()

		$(document).off('focusin.modal')

		this.$element
			.removeClass('in')
			.off('click.dismiss.modal')
			.off('mouseup.dismiss.modal')

		this.$dialog.off('mousedown.dismiss.modal')

		$.support.transition && this.$element.hasClass('fade') ?
			this.$element
				.one('bsTransitionEnd', $.proxy(this.hideModal, this))
				.emulateTransitionEnd(Modal.TRANSITION_DURATION) :
			this.hideModal()
	},
	enforceFocus: function() {
		$(document)
			.off('focusin.modal') // guard against infinite focus loop
			.on('focusin.modal', $.proxy(function (e) {
				if (this.$element[0] !== e.target && !this.$element.has(e.target).length) {
					this.$element.trigger('focus')
				}
			}, this))
	},
	escape: function() {
		if (this.isShown && this.options.keyboard) {
			this.$element.on('keydown.dismiss.modal', $.proxy(function(e) {
				e.which == 27 && this.hide()
			}, this))
		} else if (!this.isShown) {
			this.$element.off('keydown.dismiss.modal')
		}
	},
	resize: function() {
		if (this.isShown) {
			$(window).on('resize.modal', $.proxy(this.handleUpdate, this))
		} else {
			$(window).off('resize.modal')
		}
	},
	hideModal: function() {
		var that = this
		this.$element.hide()
		this.backdrop(function() {
			that.$body.removeClass('modal-open')
			that.resetAdjustments()
			that.resetScrollbar()
			that.$element.trigger('hidden.modal')
		})
	},
	removeBackdrop: function() {
		this.$backdrop && this.$backdrop.remove()
		this.$backdrop = null
	},
	backdrop: function(callback) {
		var that = this
		var animate = this.$element.hasClass('fade') ? 'fade' : ''

		if (this.isShown && this.options.backdrop) {
			var doAnimate = $.support.transition && animate

			this.$backdrop = $(document.createElement('div'))
				.addClass('modal-backdrop ' + animate)
				.appendTo(this.$body)

			this.$element.on('click.dismiss.modal', $.proxy(function (e) {
				if (this.ignoreBackdropClick) {
					this.ignoreBackdropClick = false
					return
				}
				if (e.target !== e.currentTarget) return
				this.options.backdrop == 'static'
					? this.$element[0].focus()
					: this.hide()
			}, this))

			if (doAnimate) this.$backdrop[0].offsetWidth // force reflow

			this.$backdrop.addClass('in')

			if (!callback) return

			doAnimate ?
				this.$backdrop
					.one('bsTransitionEnd', callback)
					.emulateTransitionEnd(Modal.BACKDROP_TRANSITION_DURATION) :
				callback()

		} else if (!this.isShown && this.$backdrop) {
			this.$backdrop.removeClass('in')

			var callbackRemove = function () {
				that.removeBackdrop()
				callback && callback()
			}
			$.support.transition && this.$element.hasClass('fade') ?
				this.$backdrop
					.one('bsTransitionEnd', callbackRemove)
					.emulateTransitionEnd(Modal.BACKDROP_TRANSITION_DURATION) :
				callbackRemove()

		} else if (callback) {
			callback()
		}
	},
	// these following methods are used to handle overflowing modals
	handleUpdate: function() {
		this.adjustDialog()
	},
	adjustDialog: function() {
		var modalIsOverflowing = this.$element[0].scrollHeight > document.documentElement.clientHeight

		this.$element.css({
			paddingLeft:  !this.bodyIsOverflowing && modalIsOverflowing ? this.scrollbarWidth : '',
			paddingRight: this.bodyIsOverflowing && !modalIsOverflowing ? this.scrollbarWidth : ''
		})
	},
	resetAdjustments: function() {
		this.$element.css({
			paddingLeft: '',
			paddingRight: ''
		})
	},
	checkScrollbar: function() {
		var fullWindowWidth = window.innerWidth
		if (!fullWindowWidth) { // workaround for missing window.innerWidth in IE8
			var documentElementRect = document.documentElement.getBoundingClientRect()
			fullWindowWidth = documentElementRect.right - Math.abs(documentElementRect.left)
		}
		this.bodyIsOverflowing = document.body.clientWidth < fullWindowWidth
		this.scrollbarWidth = this.measureScrollbar()
	},
	setScrollbar: function() {
		var bodyPad = parseInt((this.$body.css('padding-right') || 0), 10)
		this.originalBodyPad = document.body.style.paddingRight || ''
		if (this.bodyIsOverflowing) this.$body.css('padding-right', bodyPad + this.scrollbarWidth)
	},
	resetScrollbar: function() {
		this.$body.css('padding-right', this.originalBodyPad)
	},
	measureScrollbar: function() {
		var scrollDiv = document.createElement('div')
		scrollDiv.className = 'modal-scrollbar-measure'
		this.$body.append(scrollDiv)
		var scrollbarWidth = scrollDiv.offsetWidth - scrollDiv.clientWidth
		this.$body[0].removeChild(scrollDiv)
		return scrollbarWidth
	}
})

module.exports = Modal
